@@ -226,7 +226,7 @@ def cli_main(args, config: Config) -> int:
             ),
             steps.StepCommand(
                 shlex.split("secrethub inject -i env.temp.yaml -o env.yaml"),
-                work_dir=f'{config.base_dir}/endpoints',
+                work_dir=f'{config.base_dir}/endpoints/{endpoint.operation_id}',
             ),
             steps.StepCommand(
                 shlex.split(runtime.command),
